==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/filestore_instance/FilestoreInstanceFileShares.java <==
package com.hashicorp.cdktf.providers.google.filestore_instance;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:41.835Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.filestoreInstance.FilestoreInstanceFileShares")
@software.amazon.jsii.Jsii.Proxy(FilestoreInstanceFileShares.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface FilestoreInstanceFileShares extends software.amazon.jsii.JsiiSerializable {

    /**
     * File share capacity in GiB.
     * <p>
     * This must be at least 1024 GiB
     * for the standard tier, or 2560 GiB for the premium tier.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/filestore_instance#capacity_gb FilestoreInstance#capacity_gb}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getCapacityGb();

    /**
     * The name of the fileshare (16 characters or less).
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/filestore_instance#name FilestoreInstance#name}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getName();

    /**
     * nfs_export_options block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/filestore_instance#nfs_export_options FilestoreInstance#nfs_export_options}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getNfsExportOptions() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link FilestoreInstanceFileShares}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link FilestoreInstanceFileShares}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<FilestoreInstanceFileShares> {
        java.lang.Number capacityGb;
        java.lang.String name;
        java.lang.Object nfsExportOptions;

        /**
         * Sets the value of {@link FilestoreInstanceFileShares#getCapacityGb}
         * @param capacityGb File share capacity in GiB. This parameter is required.
         *                   This must be at least 1024 GiB
         *                   for the standard tier, or 2560 GiB for the premium tier.
         *                   
         *                   Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/filestore_instance#capacity_gb FilestoreInstance#capacity_gb}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder capacityGb(java.lang.Number capacityGb) {
            this.capacityGb = capacityGb;
            return this;
        }

        /**
         * Sets the value of {@link FilestoreInstanceFileShares#getName}
         * @param name The name of the fileshare (16 characters or less). This parameter is required.
         *             Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/filestore_instance#name FilestoreInstance#name}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link FilestoreInstanceFileShares#getNfsExportOptions}
         * @param nfsExportOptions nfs_export_options block.
         *                         Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/filestore_instance#nfs_export_options FilestoreInstance#nfs_export_options}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder nfsExportOptions(com.hashicorp.cdktf.IResolvable nfsExportOptions) {
            this.nfsExportOptions = nfsExportOptions;
            return this;
        }

        /**
         * Sets the value of {@link FilestoreInstanceFileShares#getNfsExportOptions}
         * @param nfsExportOptions nfs_export_options block.
         *                         Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/filestore_instance#nfs_export_options FilestoreInstance#nfs_export_options}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder nfsExportOptions(java.util.List<? extends com.hashicorp.cdktf.providers.google.filestore_instance.FilestoreInstanceFileSharesNfsExportOptions> nfsExportOptions) {
            this.nfsExportOptions = nfsExportOptions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link FilestoreInstanceFileShares}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public FilestoreInstanceFileShares build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link FilestoreInstanceFileShares}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements FilestoreInstanceFileShares {
        private final java.lang.Number capacityGb;
        private final java.lang.String name;
        private final java.lang.Object nfsExportOptions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.capacityGb = software.amazon.jsii.Kernel.get(this, "capacityGb", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.nfsExportOptions = software.amazon.jsii.Kernel.get(this, "nfsExportOptions", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.capacityGb = java.util.Objects.requireNonNull(builder.capacityGb, "capacityGb is required");
            this.name = java.util.Objects.requireNonNull(builder.name, "name is required");
            this.nfsExportOptions = builder.nfsExportOptions;
        }

        @Override
        public final java.lang.Number getCapacityGb() {
            return this.capacityGb;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.Object getNfsExportOptions() {
            return this.nfsExportOptions;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("capacityGb", om.valueToTree(this.getCapacityGb()));
            data.set("name", om.valueToTree(this.getName()));
            if (this.getNfsExportOptions() != null) {
                data.set("nfsExportOptions", om.valueToTree(this.getNfsExportOptions()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.filestoreInstance.FilestoreInstanceFileShares"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            FilestoreInstanceFileShares.Jsii$Proxy that = (FilestoreInstanceFileShares.Jsii$Proxy) o;

            if (!capacityGb.equals(that.capacityGb)) return false;
            if (!name.equals(that.name)) return false;
            return this.nfsExportOptions != null ? this.nfsExportOptions.equals(that.nfsExportOptions) : that.nfsExportOptions == null;
        }

        @Override
        public final int hashCode() {
            int result = this.capacityGb.hashCode();
            result = 31 * result + (this.name.hashCode());
            result = 31 * result + (this.nfsExportOptions != null ? this.nfsExportOptions.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/filestore_instance/FilestoreInstanceFileShares.java <==
package com.hashicorp.cdktf.providers.google.filestore_instance;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:15.905Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.filestoreInstance.FilestoreInstanceFileShares")
@software.amazon.jsii.Jsii.Proxy(FilestoreInstanceFileShares.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface FilestoreInstanceFileShares extends software.amazon.jsii.JsiiSerializable {

    /**
     * File share capacity in GiB.
     * <p>
     * This must be at least 1024 GiB
     * for the standard tier, or 2560 GiB for the premium tier.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/filestore_instance#capacity_gb FilestoreInstance#capacity_gb}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getCapacityGb();

    /**
     * The name of the fileshare (16 characters or less).
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/filestore_instance#name FilestoreInstance#name}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getName();

    /**
     * nfs_export_options block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/filestore_instance#nfs_export_options FilestoreInstance#nfs_export_options}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getNfsExportOptions() {
        return null;
    }

    /**
     * The resource name of the backup, in the format projects/{projectId}/locations/{locationId}/backups/{backupId}, that this file share has been restored from.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/filestore_instance#source_backup FilestoreInstance#source_backup}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSourceBackup() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link FilestoreInstanceFileShares}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link FilestoreInstanceFileShares}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<FilestoreInstanceFileShares> {
        java.lang.Number capacityGb;
        java.lang.String name;
        java.lang.Object nfsExportOptions;
        java.lang.String sourceBackup;

        /**
         * Sets the value of {@link FilestoreInstanceFileShares#getCapacityGb}
         * @param capacityGb File share capacity in GiB. This parameter is required.
         *                   This must be at least 1024 GiB
         *                   for the standard tier, or 2560 GiB for the premium tier.
         *                   
         *                   Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/filestore_instance#capacity_gb FilestoreInstance#capacity_gb}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder capacityGb(java.lang.Number capacityGb) {
            this.capacityGb = capacityGb;
            return this;
        }

        /**
         * Sets the value of {@link FilestoreInstanceFileShares#getName}
         * @param name The name of the fileshare (16 characters or less). This parameter is required.
         *             Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/filestore_instance#name FilestoreInstance#name}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link FilestoreInstanceFileShares#getNfsExportOptions}
         * @param nfsExportOptions nfs_export_options block.
         *                         Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/filestore_instance#nfs_export_options FilestoreInstance#nfs_export_options}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder nfsExportOptions(com.hashicorp.cdktf.IResolvable nfsExportOptions) {
            this.nfsExportOptions = nfsExportOptions;
            return this;
        }

        /**
         * Sets the value of {@link FilestoreInstanceFileShares#getNfsExportOptions}
         * @param nfsExportOptions nfs_export_options block.
         *                         Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/filestore_instance#nfs_export_options FilestoreInstance#nfs_export_options}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder nfsExportOptions(java.util.List<? extends com.hashicorp.cdktf.providers.google.filestore_instance.FilestoreInstanceFileSharesNfsExportOptions> nfsExportOptions) {
            this.nfsExportOptions = nfsExportOptions;
            return this;
        }

        /**
         * Sets the value of {@link FilestoreInstanceFileShares#getSourceBackup}
         * @param sourceBackup The resource name of the backup, in the format projects/{projectId}/locations/{locationId}/backups/{backupId}, that this file share has been restored from.
         *                     Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/filestore_instance#source_backup FilestoreInstance#source_backup}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceBackup(java.lang.String sourceBackup) {
            this.sourceBackup = sourceBackup;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link FilestoreInstanceFileShares}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public FilestoreInstanceFileShares build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link FilestoreInstanceFileShares}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements FilestoreInstanceFileShares {
        private final java.lang.Number capacityGb;
        private final java.lang.String name;
        private final java.lang.Object nfsExportOptions;
        private final java.lang.String sourceBackup;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.capacityGb = software.amazon.jsii.Kernel.get(this, "capacityGb", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.nfsExportOptions = software.amazon.jsii.Kernel.get(this, "nfsExportOptions", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.sourceBackup = software.amazon.jsii.Kernel.get(this, "sourceBackup", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.capacityGb = java.util.Objects.requireNonNull(builder.capacityGb, "capacityGb is required");
            this.name = java.util.Objects.requireNonNull(builder.name, "name is required");
            this.nfsExportOptions = builder.nfsExportOptions;
            this.sourceBackup = builder.sourceBackup;
        }

        @Override
        public final java.lang.Number getCapacityGb() {
            return this.capacityGb;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.Object getNfsExportOptions() {
            return this.nfsExportOptions;
        }

        @Override
        public final java.lang.String getSourceBackup() {
            return this.sourceBackup;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("capacityGb", om.valueToTree(this.getCapacityGb()));
            data.set("name", om.valueToTree(this.getName()));
            if (this.getNfsExportOptions() != null) {
                data.set("nfsExportOptions", om.valueToTree(this.getNfsExportOptions()));
            }
            if (this.getSourceBackup() != null) {
                data.set("sourceBackup", om.valueToTree(this.getSourceBackup()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.filestoreInstance.FilestoreInstanceFileShares"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            FilestoreInstanceFileShares.Jsii$Proxy that = (FilestoreInstanceFileShares.Jsii$Proxy) o;

            if (!capacityGb.equals(that.capacityGb)) return false;
            if (!name.equals(that.name)) return false;
            if (this.nfsExportOptions != null ? !this.nfsExportOptions.equals(that.nfsExportOptions) : that.nfsExportOptions != null) return false;
            return this.sourceBackup != null ? this.sourceBackup.equals(that.sourceBackup) : that.sourceBackup == null;
        }

        @Override
        public final int hashCode() {
            int result = this.capacityGb.hashCode();
            result = 31 * result + (this.name.hashCode());
            result = 31 * result + (this.nfsExportOptions != null ? this.nfsExportOptions.hashCode() : 0);
            result = 31 * result + (this.sourceBackup != null ? this.sourceBackup.hashCode() : 0);
            return result;
        }
    }
}
